@@ -16,22 +16,27 @@ go run . bars -sz -m "\[(.+?)\].*\" (\d+)" -e "{$ {buckettime {1} year nginx} {2
 
 func bargraphFunction(c *cli.Context) error {
 	var (
-		stacked    = c.Bool("stacked")
-		sortName   = c.String(helpers.DefaultSortFlag.Name)
-		scaleName  = c.String(helpers.ScaleFlag.Name)
-		formatName = c.String(helpers.FormatFlag.Name)
+		stacked      = c.Bool("stacked")
+		inlineSubkey = c.Bool("inline-key")
+		sortName     = c.String(helpers.DefaultSortFlag.Name)
+		scaleName    = c.String(helpers.ScaleFlag.Name)
+		formatName   = c.String(helpers.FormatFlag.Name)
 	)
 
 	vt := helpers.BuildVTermFromArguments(c)
 	counter := aggregation.NewSubKeyCounter()
 	writer := termrenderers.NewBarGraph(vt)
 	writer.Stacked = stacked
+	writer.InlineSubkey = inlineSubkey
 	if c.IsSet(helpers.ScaleFlag.Name) {
 		if stacked {
 			return cli.Exit("Unable to set graph scale on stacked graphs", helpers.ExitCodeInvalidUsage)
 		}
 		writer.Scaler = helpers.BuildScalerOrFail(scaleName)
 	}
+	if stacked && inlineSubkey {
+		return cli.Exit("Unable to use inline-key on stacked graphs", helpers.ExitCodeInvalidUsage)
+	}
 	writer.Formatter = helpers.BuildFormatterOrFail(formatName)
 
 	batcher := helpers.BuildBatcherFromArguments(c)
@@ -47,7 +52,7 @@ func bargraphFunction(c *cli.Context) error {
 			line++
 		}
 
-		writer.WriteFooter(0, helpers.FWriteExtractorSummary(ext, counter.ParseErrors()))
+		writer.WriteFooter(0, helpers.BuildExtractorSummary(ext, counter.ParseErrors()))
 		writer.WriteFooter(1, batcher.StatusString())
 	})
 
@@ -77,6 +82,11 @@ func bargraphCommand() *cli.Command {
 				Aliases: []string{"s"},
 				Usage:   "Display bargraph as stacked",
 			},
+			&cli.BoolFlag{
+				Name:    "inline-key",
+				Aliases: []string{"k"},
+				Usage:   "For unstacked graph, display subkey on each bar",
+			},
 			helpers.DefaultSortFlag,
 			helpers.SnapshotFlag,
 			helpers.NoOutFlag,
