@@ -1,9 +1,10 @@
 package helpers
 
 import (
-	"rare/pkg/logger"
 	"testing"
 
+	"github.com/zix99/rare/pkg/logger"
+
 	"github.com/stretchr/testify/assert"
 )
 
