@@ -16,7 +16,7 @@ func TestReduce(t *testing.T) {
 		`-m (\d+) --snapshot -a "test={sumi {.} {0}}" testdata/log.txt`)
 	assert.NoError(t, err)
 	assert.Empty(t, eout)
-	assert.Equal(t, "test: 32\nMatched: 3 / 6\n96 B (0 B/s) \n", out)
+	testutil.AssertPattern(t, out, "test: 32\nMatched: 3 / 6\n96 B in * (*)\n")
 }
 
 func TestReduceBasics(t *testing.T) {
