@@ -8,3 +8,10 @@ const FalsyVal = ""
 func Truthy(s string) bool {
 	return strings.TrimSpace(s) != FalsyVal
 }
+
+func TruthyStr(is bool) string {
+	if is {
+		return TruthyVal
+	}
+	return FalsyVal
+}
