@@ -6,13 +6,14 @@ import (
 	"time"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/zix99/rare/pkg/testutil"
 )
 
 func TestBatchFollowFile(t *testing.T) {
 	filenames := make(chan string, 1)
 	filenames <- "tailBatcher_test.go" // me
 
-	batcher := TailFilesToChan(filenames, 5, 1, false, false, false)
+	batcher := TailFilesToChan(filenames, 5, 1, 1024, false, false, false)
 
 	batch := <-batcher.BatchChan()
 	assert.Equal(t, "tailBatcher_test.go", batch.Source)
@@ -21,6 +22,8 @@ func TestBatchFollowFile(t *testing.T) {
 }
 
 func TestBatchFollowTailFile(t *testing.T) {
+	testutil.SkipWindows(t) // Not working right now
+
 	tmp, err := os.CreateTemp("", "followtest-")
 	if err != nil {
 		panic(err)
@@ -37,7 +40,7 @@ func TestBatchFollowTailFile(t *testing.T) {
 	filenames := make(chan string, 1)
 	filenames <- tmp.Name()
 
-	batcher := TailFilesToChan(filenames, 1, 1, false, false, true)
+	batcher := TailFilesToChan(filenames, 1, 1, 1024, false, false, true)
 
 	for batcher.ActiveFileCount() == 0 {
 		time.Sleep(time.Millisecond) // Semi-hack: Wait for the go-routine reader to start and the source to be drained
