@@ -3,9 +3,10 @@
 package fastregex
 
 import (
-	"rare/pkg/testutil"
 	"testing"
 
+	"github.com/zix99/rare/pkg/testutil"
+
 	"github.com/stretchr/testify/assert"
 )
 
