@@ -1,9 +1,10 @@
 package termrenderers
 
 import (
-	"rare/pkg/multiterm"
 	"testing"
 
+	"github.com/zix99/rare/pkg/multiterm"
+
 	"github.com/stretchr/testify/assert"
 )
 
